@@ -25,10 +25,14 @@ def upload_static_file(path):
     return requests.request("POST", url, headers=headers, data=payload, files=files).json()
 
 
-def upload_file(path):
+def upload_file(path, retries=3):
     dh = DriverHelper()
     x = dh.upload_file_auto("studio-result", [path])
-    return x[0].split(";;")[-1]
+    rs = x[0].split(";;")[-1]
+    if rs == 'None':
+        if retries > 0:
+            return upload_file(path, retries-1)
+    return rs
 def upload_file_resource(path):
     dh = DriverHelper()
     x = dh.upload_file_auto("studio", [path])
